// Copyright (c) 2021 Beta Kuang <beta.kuang@gmail.com>
//
// This software is provided 'as-is', without any express or implied
// warranty. In no event will the authors be held liable for any damages
// arising from the use of this software.
//
// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it
// freely, subject to the following restrictions:
//
// 1. The origin of this software must not be misrepresented; you must not
//    claim that you wrote the original software. If you use this software
//    in a product, an acknowledgment in the product documentation would be
//    appreciated but is not required.
// 2. Altered source versions must be plainly marked as such, and must not be
//    misrepresented as being the original software.
// 3. This notice may not be removed or altered from any source distribution.

package main

import (
	"flag"

	"dlercloud-telegarm-bot/internal/bot"
	"dlercloud-telegarm-bot/internal/config"
	"dlercloud-telegarm-bot/internal/log"
)

func main() {
	parseArgs()
	parseConfig()
	startBot()
}

var (
	cfg        *config.Config
	configPath string
)

func parseArgs() {
	flag.StringVar(&configPath, "c", "config.toml", "config file path")
	flag.Parse()

	// Validate
	if len(configPath) <= 0 {
		log.Fatalf("missing config file path")
	}
}

func parseConfig() {
	c, err := config.FromFile(configPath)
	if err != nil {
		log.Fatalf("failed to parse config file, error: %+v", err)
	}

	cfg = c
}

func startBot() {
	bot := bot.NewBot(cfg)
	if err := bot.Start(); err != nil {
		log.Fatalf("failed to start bot, error: %+v", err)
	}
}
